Date: 2022-10-01T06:39:39+00:00

Actual source code: slepcrg.h
slepc-3.18.0 2022-10-01
Report Typos and Errors

      1: !
      2: !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      3: !  SLEPc - Scalable Library for Eigenvalue Problem Computations
      4: !  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
      5: !
      6: !  This file is part of SLEPc.
      7: !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
      8: !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      9: !
     10: !  Used by slepcrgmod.F90 to create Fortran module file
     11: !
     12: #include "slepc/finclude/slepcrg.h"

     14:       type tRG
     15:         PetscFortranAddr:: v PETSC_FORTRAN_TYPE_INITIALIZE
     16:       end type tRG

     18:       RG, parameter :: SLEPC_NULL_RG = tRG(0)

     20:       PetscEnum, parameter :: RG_QUADRULE_TRAPEZOIDAL = 1
     21:       PetscEnum, parameter :: RG_QUADRULE_CHEBYSHEV   = 2

     23: #if defined(_WIN32) && defined(PETSC_USE_SHARED_LIBRARIES)
     24: !DEC$ ATTRIBUTES DLLEXPORT::SLEPC_NULL_RG
     25: #endif